@@ -33,7 +33,7 @@ NULL
 #' @param maxgroups maximum number of groups to work over (intentionally not enforced if \code{partitionMethod=='group_by'})
 #' @param eagerCompute logical, if TRUE call compute on split results
 #' @param restoreGroup logical, if TRUE restore group column after apply when \code{partitionMethod \%in\% c('extract', 'split')}
-#' @param tempNameGenerator temp name generator produced by \code{cdata::makeTempNameGenerator}, used to record \code{dplyr::compute()} effects.
+#' @param tempNameGenerator temp name generator produced by \code{wrapr::mk_tmp_name_source}, used to record \code{dplyr::compute()} effects.
 #' @return transformed frame
 #'
 #' @examples
@@ -101,7 +101,7 @@ gapply <- function(df,gcolumn,f,
                    maxgroups=100,
                    eagerCompute=FALSE,
                    restoreGroup=FALSE,
-                   tempNameGenerator= makeTempNameGenerator("replyr_gapply")) {
+                   tempNameGenerator= mk_tmp_name_source("replyr_gapply")) {
   if((!is.character(gcolumn))||(length(gcolumn)!=1)||(nchar(gcolumn)<1)) {
     stop('replyr::gapply gcolumn must be a single non-empty string')
   }
