@@ -72,8 +72,10 @@ d %>% replyr::gapply('group', rank_in_group, ocolumn='order', decreasing=TRUE)
 ## ----summaryexample-------------------------------------------------------------------------------
 d <- data.frame(x=c(1,2,2),y=c(3,5,NA),z=c(NA,'a','b'),
                 stringsAsFactors = FALSE)
-if (requireNamespace("RSQLite")) {
-  my_db <- dplyr::src_sqlite(":memory:", create = TRUE)
+if (requireNamespace("RSQLite", quietly = TRUE) && 
+    requireNamespace("dbplyr", quietly = TRUE)) {
+  my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
+  RSQLite::initExtension(my_db)
   dRemote <- replyr::replyr_copy_to(my_db,d,'d')
 } else {
   dRemote <- d # local stand in when we can't make remote
@@ -91,6 +93,7 @@ values <- c(2)
 dRemote %>% replyr::replyr_filter('x', values)
 
 ## -------------------------------------------------------------------------------------------------
+DBI::dbDisconnect(my_db)
 rm(list=ls())
 gc()
 
